@@ -23,7 +23,7 @@
 #ifndef MINUET_IEXERCISECONTROLLER_H
 #define MINUET_IEXERCISECONTROLLER_H
 
-#include "minuetinterfacesexport.h"
+#include <interfaces/minuetinterfacesexport.h>
 
 #include <QObject>
 #include <QJsonArray>
@@ -42,6 +42,8 @@ class MINUETINTERFACES_EXPORT IExerciseController : public QObject
 
 public:
     virtual ~IExerciseController() override;
+    
+    virtual QString errorString() const = 0;
 
     virtual QJsonArray exercises() const = 0;
     void setCurrentExercise(QVariantMap currentExercise);
